@@ -15,11 +15,12 @@ func DBImport(app clio.Application) *cobra.Command {
 	opts := dbOptionsDefault(app.ID())
 
 	return app.SetupCommand(&cobra.Command{
-		Use:   "import FILE",
-		Short: "import a vulnerability database archive",
-		Long:  fmt.Sprintf("import a vulnerability database archive from a local FILE.\nDB archives can be obtained from %q.", internal.DBUpdateURL),
-		Args:  cobra.ExactArgs(1),
-		RunE: func(cmd *cobra.Command, args []string) error {
+		Use:     "import FILE",
+		Short:   "import a vulnerability database archive",
+		Long:    fmt.Sprintf("import a vulnerability database archive from a local FILE.\nDB archives can be obtained from %q.", internal.DBUpdateURL),
+		Args:    cobra.ExactArgs(1),
+		PreRunE: disableUI(app),
+		RunE: func(_ *cobra.Command, args []string) error {
 			return runDBImport(opts.DB, args[0])
 		},
 	}, opts)
