@@ -14,10 +14,11 @@ func DBStatus(app clio.Application) *cobra.Command {
 	opts := dbOptionsDefault(app.ID())
 
 	return app.SetupCommand(&cobra.Command{
-		Use:   "status",
-		Short: "display database status",
-		Args:  cobra.ExactArgs(0),
-		RunE: func(cmd *cobra.Command, args []string) error {
+		Use:      "status",
+		Short:    "display database status",
+		Args:     cobra.ExactArgs(0),
+		PostRunE: disableUI(app),
+		RunE: func(_ *cobra.Command, _ []string) error {
 			return runDBStatus(opts.DB)
 		},
 	}, opts)
