@@ -19,7 +19,7 @@ func DBUpdate(app clio.Application) *cobra.Command {
 		Use:   "update",
 		Short: "download the latest vulnerability database",
 		Args:  cobra.ExactArgs(0),
-		RunE: func(cmd *cobra.Command, args []string) error {
+		RunE: func(_ *cobra.Command, _ []string) error {
 			return runDBUpdate(opts.DB)
 		},
 	}, opts)
