@@ -2,8 +2,6 @@ package store
 
 import (
 	"encoding/json"
-	"io/ioutil"
-	"os"
 	"sort"
 	"testing"
 	"time"
@@ -30,13 +28,9 @@ func assertIDReader(t *testing.T, reader v3.IDReader, expected v3.ID) {
 }
 
 func TestStore_GetID_SetID(t *testing.T) {
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s, err := New(dbTempFile.Name(), true)
+	s, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
@@ -73,13 +67,8 @@ func assertVulnerabilityReader(t *testing.T, reader v3.VulnerabilityStoreReader,
 }
 
 func TestStore_GetVulnerability_SetVulnerability(t *testing.T) {
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
-
-	s, err := New(dbTempFile.Name(), true)
+	dbTempFile := t.TempDir()
+	s, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
@@ -253,13 +242,9 @@ type CustomMetadata struct {
 }
 
 func TestStore_GetVulnerabilityMetadata_SetVulnerabilityMetadata(t *testing.T) {
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s, err := New(dbTempFile.Name(), true)
+	s, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
@@ -727,12 +712,7 @@ func TestStore_MergeVulnerabilityMetadata(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			dbTempDir, err := ioutil.TempDir("", "grype-db-test-store")
-			if err != nil {
-				t.Fatalf("could not create temp file: %+v", err)
-			}
-			defer os.RemoveAll(dbTempDir)
-
+			dbTempDir := t.TempDir()
 			s, err := New(dbTempDir, true)
 			if err != nil {
 				t.Fatalf("could not create store: %+v", err)
@@ -1000,11 +980,7 @@ func TestCvssScoresInMetadata(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			dbTempDir, err := ioutil.TempDir("", "grype-db-test-s")
-			if err != nil {
-				t.Fatalf("could not create temp file: %+v", err)
-			}
-			defer os.RemoveAll(dbTempDir)
+			dbTempDir := t.TempDir()
 
 			s, err := New(dbTempDir, true)
 			if err != nil {
@@ -1033,23 +1009,15 @@ func TestCvssScoresInMetadata(t *testing.T) {
 
 func Test_DiffStore(t *testing.T) {
 	//GIVEN
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s1, err := New(dbTempFile.Name(), true)
+	s1, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
-	dbTempFile, err = ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile = t.TempDir()
 
-	s2, err := New(dbTempFile.Name(), true)
+	s2, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
