@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"sort"
 
+	_ "github.com/glebarez/sqlite" // provide the sqlite dialect to gorm via import
 	"github.com/go-test/deep"
 	"gorm.io/gorm"
 
@@ -11,7 +12,6 @@ import (
 	v5 "github.com/anchore/grype/grype/db/v5"
 	"github.com/anchore/grype/grype/db/v5/store/model"
 	"github.com/anchore/grype/internal/stringutil"
-	_ "github.com/anchore/sqlite" // provide the sqlite dialect to gorm via import
 )
 
 // store holds an instance of the database connection
@@ -325,37 +325,45 @@ func (s *store) GetAllVulnerabilityMetadata() (*[]v5.VulnerabilityMetadata, erro
 
 // DiffStore creates a diff between the current sql database and the given store
 func (s *store) DiffStore(targetStore v5.StoreReader) (*[]v5.Diff, error) {
-	rowsProgress, diffItems := trackDiff()
+	// 7 stages, one for each step of the diff process (stages)
+	rowsProgress, diffItems, stager := trackDiff(7)
 
+	stager.Current = "reading target vulnerabilities"
 	targetVulns, err := targetStore.GetAllVulnerabilities()
 	rowsProgress.Increment()
 	if err != nil {
 		return nil, err
 	}
 
+	stager.Current = "reading base vulnerabilities"
 	baseVulns, err := s.GetAllVulnerabilities()
 	rowsProgress.Increment()
 	if err != nil {
 		return nil, err
 	}
 
+	stager.Current = "preparing"
 	baseVulnPkgMap := buildVulnerabilityPkgsMap(baseVulns)
 	targetVulnPkgMap := buildVulnerabilityPkgsMap(targetVulns)
 
+	stager.Current = "comparing vulnerabilities"
 	allDiffsMap := diffVulnerabilities(baseVulns, targetVulns, baseVulnPkgMap, targetVulnPkgMap, diffItems)
 
+	stager.Current = "reading base metadata"
 	baseMetadata, err := s.GetAllVulnerabilityMetadata()
 	if err != nil {
 		return nil, err
 	}
 	rowsProgress.Increment()
 
+	stager.Current = "reading target metadata"
 	targetMetadata, err := targetStore.GetAllVulnerabilityMetadata()
 	if err != nil {
 		return nil, err
 	}
 	rowsProgress.Increment()
 
+	stager.Current = "comparing metadata"
 	metaDiffsMap := diffVulnerabilityMetadata(baseMetadata, targetMetadata, baseVulnPkgMap, targetVulnPkgMap, diffItems)
 	for k, diff := range *metaDiffsMap {
 		(*allDiffsMap)[k] = diff
