@@ -14,6 +14,8 @@ const (
 	MsrcMatcher        MatcherType = "msrc-matcher"
 	PortageMatcher     MatcherType = "portage-matcher"
 	GoModuleMatcher    MatcherType = "go-module-matcher"
+	OpenVexMatcher     MatcherType = "openvex-matcher"
+	RustMatcher        MatcherType = "rust-matcher"
 )
 
 var AllMatcherTypes = []MatcherType{
@@ -28,6 +30,8 @@ var AllMatcherTypes = []MatcherType{
 	MsrcMatcher,
 	PortageMatcher,
 	GoModuleMatcher,
+	OpenVexMatcher,
+	RustMatcher,
 }
 
 type MatcherType string
