@@ -160,10 +160,10 @@ func TestNew(t *testing.T) {
 				Name: "sqlite",
 				Metadata: syftPkg.RpmArchive{
 					SourceRpm:       "sqlite-3.26.0-6.el8.src.rpm",
-					ModularityLabel: "abc:2",
+					ModularityLabel: strRef("abc:2"),
 				},
 			},
-			metadata: RpmMetadata{ModularityLabel: "abc:2"},
+			metadata: RpmMetadata{ModularityLabel: strRef("abc:2")},
 		},
 		{
 			name: "java pkg",
@@ -171,12 +171,18 @@ func TestNew(t *testing.T) {
 				Metadata: syftPkg.JavaArchive{
 					VirtualPath: "virtual-path-info",
 					Manifest: &syftPkg.JavaManifest{
-						Main: map[string]string{
-							"Name": "main-section-name-info",
+						Main: syftPkg.KeyValues{
+							{
+								Key:   "Name",
+								Value: "main-section-name-info",
+							},
 						},
-						NamedSections: map[string]map[string]string{
-							"named-section": {
-								"named-section-key": "named-section-value",
+						Sections: []syftPkg.KeyValues{
+							{
+								{
+									Key:   "named-section-key",
+									Value: "named-section-value",
+								},
 							},
 						},
 					},
@@ -227,6 +233,7 @@ func TestNew(t *testing.T) {
 					Name: "libcurl",
 				},
 			},
+			metadata: ApkMetadata{Files: []ApkFileRecord{}},
 		},
 		// the below packages are those that have no metadata or upstream info to parse out
 		{
@@ -287,14 +294,14 @@ func TestNew(t *testing.T) {
 			name: "golang-metadata",
 			syftPkg: syftPkg.Package{
 				Metadata: syftPkg.GolangBinaryBuildinfoEntry{
-					BuildSettings:     map[string]string{},
+					BuildSettings:     syftPkg.KeyValues{},
 					GoCompiledVersion: "1.0.0",
 					H1Digest:          "a",
 					MainModule:        "myMainModule",
 				},
 			},
 			metadata: GolangBinMetadata{
-				BuildSettings:     map[string]string{},
+				BuildSettings:     syftPkg.KeyValues{},
 				GoCompiledVersion: "1.0.0",
 				H1Digest:          "a",
 				MainModule:        "myMainModule",
@@ -359,19 +366,34 @@ func TestNew(t *testing.T) {
 			},
 		},
 		{
-			name: "cpp conan lock metadata",
+			name: "cpp conan v1 lock metadata",
 			syftPkg: syftPkg.Package{
-				Metadata: syftPkg.ConanLockEntry{
+				Metadata: syftPkg.ConanV1LockEntry{
 					Ref: "zlib/1.2.12",
-					Options: map[string]string{
-						"fPIC":   "True",
-						"shared": "False",
+					Options: syftPkg.KeyValues{
+						{
+							Key:   "fPIC",
+							Value: "True",
+						},
+						{
+							Key:   "shared",
+							Value: "false",
+						},
 					},
 					Path:    "all/conanfile.py",
 					Context: "host",
 				},
 			},
 		},
+		{
+			name: "cpp conan v2 lock metadata",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.ConanV2LockEntry{
+					Ref:       "zlib/1.2.12",
+					PackageID: "some-id",
+				},
+			},
+		},
 		{
 			name: "cocoapods cocoapods-metadata",
 			syftPkg: syftPkg.Package{
@@ -578,6 +600,67 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "python-poetry-lock-entry",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.PythonPoetryLockEntry{Index: "some-index"},
+			},
+		},
+		{
+			name: "yarn-lock-entry",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.YarnLockEntry{
+					Resolved:  "some-resolution",
+					Integrity: "some-digest",
+				},
+			},
+		},
+		{
+			name: "wordpress-plugin-entry",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.WordpressPluginEntry{
+					PluginInstallDirectory: "a",
+					Author:                 "a",
+					AuthorURI:              "a",
+				},
+			},
+		},
+		{
+			name: "elf-binary-package",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.ELFBinaryPackageNoteJSONPayload{
+					Type:       "a",
+					Vendor:     "a",
+					System:     "a",
+					SourceRepo: "a",
+					Commit:     "a",
+				},
+			},
+		},
+		{
+			name: "Php-pecl-entry",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.PhpPeclEntry{
+					Name:    "a",
+					Version: "a",
+					License: []string{"a"},
+				},
+			},
+		},
+		{
+			name: "lua-rocks-entry",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.LuaRocksPackage{
+					Name:         "a",
+					Version:      "a",
+					License:      "a",
+					Homepage:     "a",
+					Description:  "a",
+					URL:          "a",
+					Dependencies: map[string]string{"b": "c"},
+				},
+			},
+		},
 	}
 
 	// capture each observed metadata type, we should see all of them relate to what syft provides by the end of testing
@@ -805,7 +888,7 @@ func catalogWithOverlaps(packages []string, overlaps []string) *sbom.SBOM {
 		pkgs = append(pkgs, p)
 	}
 
-	for _, overlap := range overlaps {
+	for i, overlap := range overlaps {
 		parts := strings.Split(overlap, "->")
 		if len(parts) < 2 {
 			panic("invalid overlap, use -> to specify, e.g.: pkg1->pkg2")
@@ -813,11 +896,24 @@ func catalogWithOverlaps(packages []string, overlaps []string) *sbom.SBOM {
 		from := toPkg(parts[0])
 		to := toPkg(parts[1])
 
-		relationships = append(relationships, artifact.Relationship{
-			From: from,
-			To:   to,
-			Type: artifact.OwnershipByFileOverlapRelationship,
-		})
+		// The catalog will type check whether To or From is a pkg.Package or a *pkg.Package.
+		// Previously, there was a bug where Grype assumed that From was always a pkg.Package.
+		// Therefore, intentionally mix pointer and non-pointer packages to prevent Grype from
+		// assuming which is which again. (The correct usage, calling catalog.Package, always
+		// returns a *pkg.Package, and doesn't rely on any type assertion.)
+		if i%2 == 0 {
+			relationships = append(relationships, artifact.Relationship{
+				From: &from,
+				To:   &to,
+				Type: artifact.OwnershipByFileOverlapRelationship,
+			})
+		} else {
+			relationships = append(relationships, artifact.Relationship{
+				From: from,
+				To:   to,
+				Type: artifact.OwnershipByFileOverlapRelationship,
+			})
+		}
 	}
 
 	catalog := syftPkg.NewCollection(pkgs...)
@@ -836,3 +932,7 @@ func withDistro(s *sbom.SBOM, id string) *sbom.SBOM {
 	}
 	return s
 }
+
+func strRef(s string) *string {
+	return &s
+}
