@@ -12,7 +12,7 @@ import (
 
 	"github.com/anchore/grype/internal"
 	"github.com/anchore/grype/internal/log"
-	"github.com/anchore/syft/syft"
+	"github.com/anchore/syft/syft/format"
 	"github.com/anchore/syft/syft/sbom"
 )
 
@@ -56,19 +56,19 @@ func getSBOM(userInput string) (*sbom.SBOM, error) {
 		return nil, err
 	}
 
-	s, format, err := syft.Decode(reader)
+	s, fmtID, _, err := format.Decode(reader)
 	if err != nil {
 		return nil, fmt.Errorf("unable to decode sbom: %w", err)
 	}
 
-	if format == nil {
+	if fmtID == "" || s == nil {
 		return nil, errDoesNotProvide
 	}
 
 	return s, nil
 }
 
-func getSBOMReader(userInput string) (r io.Reader, err error) {
+func getSBOMReader(userInput string) (r io.ReadSeeker, err error) {
 	r, _, err = extractReaderAndInfo(userInput)
 	if err != nil {
 		return nil, err
@@ -77,7 +77,7 @@ func getSBOMReader(userInput string) (r io.Reader, err error) {
 	return r, nil
 }
 
-func extractReaderAndInfo(userInput string) (io.Reader, *inputInfo, error) {
+func extractReaderAndInfo(userInput string) (io.ReadSeeker, *inputInfo, error) {
 	switch {
 	// the order of cases matter
 	case userInput == "":
@@ -97,7 +97,7 @@ func extractReaderAndInfo(userInput string) (io.Reader, *inputInfo, error) {
 	}
 }
 
-func parseSBOM(scheme, path string) (io.Reader, *inputInfo, error) {
+func parseSBOM(scheme, path string) (io.ReadSeeker, *inputInfo, error) {
 	r, err := openFile(path)
 	if err != nil {
 		return nil, nil, err
@@ -106,7 +106,7 @@ func parseSBOM(scheme, path string) (io.Reader, *inputInfo, error) {
 	return r, info, nil
 }
 
-func decodeStdin(r io.Reader) (io.Reader, *inputInfo, error) {
+func decodeStdin(r io.Reader) (io.ReadSeeker, *inputInfo, error) {
 	b, err := io.ReadAll(r)
 	if err != nil {
 		return nil, nil, fmt.Errorf("failed reading stdin: %w", err)
