@@ -14,13 +14,15 @@ type IgnoreRule struct {
 	Package          *IgnoreRulePackage `json:"package,omitempty"`
 	VexStatus        string             `json:"vex-status,omitempty"`
 	VexJustification string             `json:"vex-justification,omitempty"`
+	MatchType        string             `json:"match-type,omitempty"`
 }
 
 type IgnoreRulePackage struct {
-	Name     string `json:"name,omitempty"`
-	Version  string `json:"version,omitempty"`
-	Type     string `json:"type,omitempty"`
-	Location string `json:"location,omitempty"`
+	Name         string `json:"name,omitempty"`
+	Version      string `json:"version,omitempty"`
+	Type         string `json:"type,omitempty"`
+	Location     string `json:"location,omitempty"`
+	UpstreamName string `json:"upstream-name,omitempty"`
 }
 
 func newIgnoreRule(r match.IgnoreRule) IgnoreRule {
@@ -29,10 +31,11 @@ func newIgnoreRule(r match.IgnoreRule) IgnoreRule {
 	// We'll only set the package part of the rule not to `nil` if there are any values to fill out.
 	if p := r.Package; p.Name != "" || p.Version != "" || p.Type != "" || p.Location != "" {
 		ignoreRulePackage = &IgnoreRulePackage{
-			Name:     r.Package.Name,
-			Version:  r.Package.Version,
-			Type:     r.Package.Type,
-			Location: r.Package.Location,
+			Name:         r.Package.Name,
+			Version:      r.Package.Version,
+			Type:         r.Package.Type,
+			Location:     r.Package.Location,
+			UpstreamName: r.Package.UpstreamName,
 		}
 	}
 
@@ -43,6 +46,7 @@ func newIgnoreRule(r match.IgnoreRule) IgnoreRule {
 		Package:          ignoreRulePackage,
 		VexStatus:        r.VexStatus,
 		VexJustification: r.VexJustification,
+		MatchType:        string(r.MatchType),
 	}
 }
 
