@@ -18,7 +18,7 @@ func TestNewSource(t *testing.T) {
 		{
 			name: "image",
 			metadata: syftSource.Description{
-				Metadata: syftSource.StereoscopeImageSourceMetadata{
+				Metadata: syftSource.ImageMetadata{
 					UserInput:      "abc",
 					ID:             "def",
 					ManifestDigest: "abcdef",
@@ -27,7 +27,7 @@ func TestNewSource(t *testing.T) {
 			},
 			expected: source{
 				Type: "image",
-				Target: syftSource.StereoscopeImageSourceMetadata{
+				Target: syftSource.ImageMetadata{
 					UserInput:      "abc",
 					ID:             "def",
 					ManifestDigest: "abcdef",
@@ -40,7 +40,7 @@ func TestNewSource(t *testing.T) {
 		{
 			name: "directory",
 			metadata: syftSource.Description{
-				Metadata: syftSource.DirectorySourceMetadata{
+				Metadata: syftSource.DirectoryMetadata{
 					Path: "/foo/bar",
 				},
 			},
@@ -52,7 +52,7 @@ func TestNewSource(t *testing.T) {
 		{
 			name: "file",
 			metadata: syftSource.Description{
-				Metadata: syftSource.FileSourceMetadata{
+				Metadata: syftSource.FileMetadata{
 					Path: "/foo/bar/test.zip",
 				},
 			},
