@@ -1,9 +1,12 @@
 package sarif
 
 import (
+	"crypto/sha256"
 	"fmt"
+	"hash"
 	"io"
 	"path/filepath"
+	"regexp"
 	"strings"
 
 	"github.com/owenrumney/go-sarif/sarif"
@@ -170,9 +173,9 @@ func (pres *Presenter) inputPath() string {
 	}
 	var inputPath string
 	switch m := pres.src.Metadata.(type) {
-	case source.FileSourceMetadata:
+	case source.FileMetadata:
 		inputPath = m.Path
-	case source.DirectorySourceMetadata:
+	case source.DirectoryMetadata:
 		inputPath = m.Path
 	default:
 		return ""
@@ -186,15 +189,12 @@ func (pres *Presenter) inputPath() string {
 
 // locationPath returns a path for the location, relative to the cwd
 func (pres *Presenter) locationPath(l file.Location) string {
-	path := l.RealPath
-	if l.VirtualPath != "" {
-		path = l.VirtualPath
-	}
+	path := l.Path()
 	in := pres.inputPath()
 	path = strings.TrimPrefix(path, "./")
 	// trimmed off any ./ and accounted for dir:. for both path and input path
 	if pres.src != nil {
-		_, ok := pres.src.Metadata.(source.DirectorySourceMetadata)
+		_, ok := pres.src.Metadata.(source.DirectoryMetadata)
 		if ok {
 			if filepath.IsAbs(path) || in == "" {
 				return path
@@ -214,23 +214,24 @@ func (pres *Presenter) locations(m match.Match) []*sarif.Location {
 	var logicalLocations []*sarif.LogicalLocation
 
 	switch metadata := pres.src.Metadata.(type) {
-	case source.StereoscopeImageSourceMetadata:
+	case source.ImageMetadata:
 		img := metadata.UserInput
 		locations := m.Package.Locations.ToSlice()
 		for _, l := range locations {
-			trimmedPath := strings.TrimPrefix(pres.locationPath(l), "/")
+			trimmedPath := strings.TrimLeft(pres.locationPath(l), "/")
 			logicalLocations = append(logicalLocations, &sarif.LogicalLocation{
 				FullyQualifiedName: sp(fmt.Sprintf("%s@%s:/%s", img, l.FileSystemID, trimmedPath)),
 				Name:               sp(l.RealPath),
 			})
 		}
 
-		// this is a hack to get results to show up in GitHub, as it requires relative paths for the location
-		// but we really won't have any information about what Dockerfile on the filesystem was used to build the image
-		// TODO we could add configuration to specify the prefix, a user might want to specify an image name and architecture
-		// in the case of multiple vuln scans, for example
-		physicalLocation = fmt.Sprintf("image/%s", physicalLocation)
-	case source.FileSourceMetadata:
+		// GitHub requires paths for the location, but we really don't have any information about what
+		// file(s) these originated from in the repository. e.g. which Dockerfile was used to build an image,
+		// so we just use a short path-compatible image name here, not the entire user input as it may include
+		// sha and/or tags which are likely to change between runs and aren't really necessary for a general
+		// path to find file where the package originated
+		physicalLocation = fmt.Sprintf("%s/%s", imageShortPathName(pres.src), physicalLocation)
+	case source.FileMetadata:
 		locations := m.Package.Locations.ToSlice()
 		for _, l := range locations {
 			logicalLocations = append(logicalLocations, &sarif.LogicalLocation{
@@ -238,7 +239,7 @@ func (pres *Presenter) locations(m match.Match) []*sarif.Location {
 				Name:               sp(l.RealPath),
 			})
 		}
-	case source.DirectorySourceMetadata:
+	case source.DirectoryMetadata:
 		// DirectoryScheme is already handled, with input prepended if needed
 	}
 
@@ -390,11 +391,12 @@ func (pres *Presenter) sarifResults() []*sarif.Result {
 		out = append(out, &sarif.Result{
 			RuleID:  sp(pres.ruleID(m)),
 			Message: pres.resultMessage(m),
-			// According to the SARIF spec, I believe we should be using AnalysisTarget.URI to indicate a logical
+			// According to the SARIF spec, it may be correct to use AnalysisTarget.URI to indicate a logical
 			// file such as a "Dockerfile" but GitHub does not work well with this
-			// FIXME github "requires" partialFingerprints
-			// PartialFingerprints: ???
-			Locations: pres.locations(m),
+			// GitHub requires partialFingerprints to upload to the API; these are automatically filled in
+			// when using the CodeQL upload action. See: https://docs.github.com/en/code-security/code-scanning/integrating-with-code-scanning/sarif-support-for-code-scanning#providing-data-to-track-code-scanning-alerts-across-runs
+			PartialFingerprints: pres.partialFingerprints(m),
+			Locations:           pres.locations(m),
 		})
 	}
 	return out
@@ -412,19 +414,40 @@ func sp(sarif string) *string {
 
 func (pres *Presenter) resultMessage(m match.Match) sarif.Message {
 	path := pres.packagePath(m.Package)
-	message := fmt.Sprintf("The path %s reports %s at version %s ", path, m.Package.Name, m.Package.Version)
-
-	if _, ok := pres.src.Metadata.(source.DirectorySourceMetadata); ok {
-		message = fmt.Sprintf("%s which would result in a vulnerable (%s) package installed", message, m.Package.Type)
-	} else {
-		message = fmt.Sprintf("%s which is a vulnerable (%s) package installed in the container", message, m.Package.Type)
+	src := pres.inputPath()
+	switch meta := pres.src.Metadata.(type) {
+	case source.ImageMetadata:
+		src = fmt.Sprintf("in image %s at: %s", meta.UserInput, path)
+	case source.FileMetadata, source.DirectoryMetadata:
+		src = fmt.Sprintf("at: %s", path)
 	}
+	message := fmt.Sprintf("A %s vulnerability in %s package: %s, version %s was found %s",
+		pres.severityText(m), m.Package.Type, m.Package.Name, m.Package.Version, src)
 
 	return sarif.Message{
 		Text: &message,
 	}
 }
 
+func (pres *Presenter) partialFingerprints(m match.Match) map[string]any {
+	p := m.Package
+	hasher := sha256.New()
+	if meta, ok := pres.src.Metadata.(source.ImageMetadata); ok {
+		hashWrite(hasher, pres.src.Name, meta.Architecture, meta.OS)
+	}
+	hashWrite(hasher, string(p.Type), p.Name, p.Version, pres.packagePath(p))
+	return map[string]any{
+		// this is meant to include <hash>:<line>, but there isn't line information here, so just include :1
+		"primaryLocationLineHash": fmt.Sprintf("%x:1", hasher.Sum([]byte{})),
+	}
+}
+
+func hashWrite(hasher hash.Hash, values ...string) {
+	for _, value := range values {
+		_, _ = hasher.Write([]byte(value))
+	}
+}
+
 func ruleName(m match.Match) string {
 	if len(m.Details) > 0 {
 		d := m.Details[0]
@@ -439,3 +462,15 @@ func ruleName(m match.Match) string {
 	}
 	return m.Vulnerability.ID
 }
+
+var nonPathChars = regexp.MustCompile("[^a-zA-Z0-9-_.]")
+
+// imageShortPathName returns path-compatible text describing the image. if the image name is the form
+// some/path/to/image, it will return the image portion of the name.
+func imageShortPathName(s *source.Description) string {
+	imageName := s.Name
+	parts := strings.Split(imageName, "/")
+	imageName = parts[len(parts)-1]
+	imageName = nonPathChars.ReplaceAllString(imageName, "")
+	return imageName
+}
