@@ -4,9 +4,11 @@ import (
 	"bytes"
 	"flag"
 	"fmt"
+	"os/exec"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/clio"
 	"github.com/anchore/go-testutils"
@@ -16,9 +18,11 @@ import (
 	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/source"
+	"github.com/anchore/syft/syft/source/directorysource"
 )
 
 var updateSnapshot = flag.Bool("update-sarif", false, "update .golden files for sarif presenters")
+var validatorImage = "ghcr.io/anchore/sarif-validator:0.1.0@sha256:a0729d695e023740f5df6bcb50d134e88149bea59c63a896a204e88f62b564c6"
 
 func TestSarifPresenter(t *testing.T) {
 	tests := []struct {
@@ -73,6 +77,58 @@ func TestSarifPresenter(t *testing.T) {
 	}
 }
 
+func Test_SarifIsValid(t *testing.T) {
+	tests := []struct {
+		name   string
+		scheme internal.SyftSource
+	}{
+		{
+			name:   "directory",
+			scheme: internal.DirectorySource,
+		},
+		{
+			name:   "image",
+			scheme: internal.ImageSource,
+		},
+	}
+
+	for _, tc := range tests {
+		t.Run(tc.name, func(t *testing.T) {
+			var buffer bytes.Buffer
+			_, matches, packages, context, metadataProvider, _, _ := internal.GenerateAnalysis(t, tc.scheme)
+
+			pb := models.PresenterConfig{
+				ID: clio.Identification{
+					Name: "grype",
+				},
+				Matches:          matches,
+				Packages:         packages,
+				Context:          context,
+				MetadataProvider: metadataProvider,
+			}
+
+			pres := NewPresenter(pb)
+			err := pres.Present(&buffer)
+			require.NoError(t, err)
+
+			cmd := exec.Command("docker", "run", "--rm", "-i", validatorImage)
+
+			out := bytes.Buffer{}
+			cmd.Stdout = &out
+			cmd.Stderr = &out
+
+			// pipe to the docker command
+			cmd.Stdin = &buffer
+
+			err = cmd.Run()
+			if err != nil || cmd.ProcessState.ExitCode() != 0 {
+				// valid
+				t.Fatalf("error validating SARIF document: %s", out.String())
+			}
+		})
+	}
+}
+
 func Test_locationPath(t *testing.T) {
 	tests := []struct {
 		name     string
@@ -83,7 +139,7 @@ func Test_locationPath(t *testing.T) {
 	}{
 		{
 			name: "dir:.",
-			metadata: source.DirectorySourceMetadata{
+			metadata: source.DirectoryMetadata{
 				Path: ".",
 			},
 			real:     "/home/usr/file",
@@ -92,7 +148,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "dir:./",
-			metadata: source.DirectorySourceMetadata{
+			metadata: source.DirectoryMetadata{
 				Path: "./",
 			},
 			real:     "/home/usr/file",
@@ -101,7 +157,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "dir:./someplace",
-			metadata: source.DirectorySourceMetadata{
+			metadata: source.DirectoryMetadata{
 				Path: "./someplace",
 			},
 			real:     "/home/usr/file",
@@ -110,7 +166,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "dir:/someplace",
-			metadata: source.DirectorySourceMetadata{
+			metadata: source.DirectoryMetadata{
 				Path: "/someplace",
 			},
 			real:     "file",
@@ -118,7 +174,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "dir:/someplace symlink",
-			metadata: source.DirectorySourceMetadata{
+			metadata: source.DirectoryMetadata{
 				Path: "/someplace",
 			},
 			real:     "/someplace/usr/file",
@@ -127,7 +183,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "dir:/someplace absolute",
-			metadata: source.DirectorySourceMetadata{
+			metadata: source.DirectoryMetadata{
 				Path: "/someplace",
 			},
 			real:     "/usr/file",
@@ -135,7 +191,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "file:/someplace/file",
-			metadata: source.FileSourceMetadata{
+			metadata: source.FileMetadata{
 				Path: "/someplace/file",
 			},
 			real:     "/usr/file",
@@ -143,7 +199,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "file:/someplace/file relative",
-			metadata: source.FileSourceMetadata{
+			metadata: source.FileMetadata{
 				Path: "/someplace/file",
 			},
 			real:     "file",
@@ -151,7 +207,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "image",
-			metadata: source.StereoscopeImageSourceMetadata{
+			metadata: source.ImageMetadata{
 				UserInput: "alpine:latest",
 			},
 			real:     "/etc/file",
@@ -159,7 +215,7 @@ func Test_locationPath(t *testing.T) {
 		},
 		{
 			name: "image symlink",
-			metadata: source.StereoscopeImageSourceMetadata{
+			metadata: source.ImageMetadata{
 				UserInput: "alpine:latest",
 			},
 			real:     "/etc/elsewhere/file",
@@ -189,7 +245,7 @@ func Test_locationPath(t *testing.T) {
 func createDirPresenter(t *testing.T) *Presenter {
 	_, matches, packages, _, metadataProvider, _, _ := internal.GenerateAnalysis(t, internal.DirectorySource)
 	d := t.TempDir()
-	s, err := source.NewFromDirectory(source.DirectoryConfig{Path: d})
+	s, err := directorysource.NewFromPath(d)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -227,8 +283,8 @@ func TestToSarifReport(t *testing.T) {
 			name:   "image",
 			scheme: internal.ImageSource,
 			locations: map[string]string{
-				"CVE-1999-0001-package-1": "image/somefile-1.txt",
-				"CVE-1999-0002-package-2": "image/somefile-2.txt",
+				"CVE-1999-0001-package-1": "user-input/somefile-1.txt",
+				"CVE-1999-0002-package-2": "user-input/somefile-2.txt",
 			},
 		},
 	}
@@ -418,3 +474,38 @@ func Test_cvssScore(t *testing.T) {
 		})
 	}
 }
+
+func Test_imageShortPathName(t *testing.T) {
+	tests := []struct {
+		name     string
+		in       string
+		expected string
+	}{
+		{
+			name:     "valid single name",
+			in:       "simple.-_name",
+			expected: "simple.-_name",
+		},
+		{
+			name:     "valid name in org",
+			in:       "some-org/some-image",
+			expected: "some-image",
+		},
+		{
+			name:     "name and org with many invalid chars",
+			in:       "some/*^&$#%$#@*(}{<><./,valid-()(#)@!(~@#$#%^&**[]{-chars",
+			expected: "valid--chars",
+		},
+	}
+
+	for _, test := range tests {
+		t.Run(test.name, func(t *testing.T) {
+			got := imageShortPathName(&source.Description{
+				Name:     test.in,
+				Metadata: nil,
+			})
+
+			assert.Equal(t, test.expected, got)
+		})
+	}
+}
