@@ -164,7 +164,8 @@ func TestSortRows(t *testing.T) {
 		{"a", "v0.1.0", "", "deb", "CVE-2018-9996", "Critical"},
 		{"a", "v0.2.0", "", "deb", "CVE-2010-9996", "High"},
 		{"b", "v0.2.0", "", "deb", "CVE-2010-9996", "Medium"},
-		{"b", "v0.2.0", "", "deb", "CVE-2019-9996", "High"},
+		{"b", "v0.2.0", "2.0.0", "deb", "CVE-2019-9996", "High"},
+		{"b", "v0.2.0", "1.0.0", "deb", "CVE-2019-9996", "High"},
 		{"d", "v0.4.0", "", "node", "CVE-2011-9996", "Low"},
 		{"d", "v0.4.0", "", "node", "CVE-2012-9996", "Negligible"},
 		{"c", "v0.6.0", "", "node", "CVE-2013-9996", "Critical"},
@@ -174,7 +175,8 @@ func TestSortRows(t *testing.T) {
 		{"a", "v0.1.0", "", "deb", "CVE-2019-9996", "Critical"},
 		{"a", "v0.1.0", "", "deb", "CVE-2018-9996", "Critical"},
 		{"a", "v0.2.0", "", "deb", "CVE-2010-9996", "High"},
-		{"b", "v0.2.0", "", "deb", "CVE-2019-9996", "High"},
+		{"b", "v0.2.0", "1.0.0", "deb", "CVE-2019-9996", "High"},
+		{"b", "v0.2.0", "2.0.0", "deb", "CVE-2019-9996", "High"},
 		{"b", "v0.2.0", "", "deb", "CVE-2010-9996", "Medium"},
 		{"c", "v0.6.0", "", "node", "CVE-2013-9996", "Critical"},
 		{"d", "v0.4.0", "", "node", "CVE-2011-9996", "Low"},
