@@ -55,9 +55,9 @@ func onlyVulnerableTargets(p pkg.Package, allVulns []vulnerability.Vulnerability
 	for _, vuln := range allVulns {
 		isPackageVulnerable := len(vuln.CPEs) == 0
 		for _, cpe := range vuln.CPEs {
-			targetSW := cpe.TargetSW
-			mismatchWithUnknownLanguage := targetSW != string(p.Language) && isUnknownTarget(targetSW)
-			if targetSW == wfn.Any || targetSW == wfn.NA || targetSW == string(p.Language) || mismatchWithUnknownLanguage {
+			targetSW := cpe.Attributes.TargetSW
+			mismatchWithUnknownLanguage := syftPkg.LanguageByName(targetSW) != p.Language && isUnknownTarget(targetSW)
+			if targetSW == wfn.Any || targetSW == wfn.NA || syftPkg.LanguageByName(targetSW) == p.Language || mismatchWithUnknownLanguage {
 				isPackageVulnerable = true
 			}
 		}
