@@ -47,6 +47,18 @@ func TestSmartVerCmp(t *testing.T) {
 		{"10.0", "1.000.0.1", 1},
 		{"1.0.4", "1.0.4+metadata", -1}, // this is also somewhat wrong, however, there is a semver parser that can handle this case (which should be leveraged when possible)
 		{"1.3.2-r0", "1.3.3-r0", -1},    // regression: regression for https://github.com/anchore/go-version/pull/2
+		// Java JRE/JDK versioning prior to the implementing https://openjdk.org/jeps/223 for >= version 9
+		{"1.8.0_456", "1.8.0", 1},
+		{"1.8.0_456", "1.8.0_234", 1},
+		{"1.8.0_456", "1.8.0_457", -1},
+		{"1.8.0_456-b1", "1.8.0_456-b2", -1},
+		{"1.8.0_456", "1.8.0_456-b1", -1},
+		// Also check the semver equivalents of pre java version 9 work as expected:
+		{"8.0.456", "8.0", 1},
+		{"8.0.456", "8.0.234", 1},
+		{"8.0.456", "8.0.457", -1},
+		{"8.0.456+1", "8.0.456+2", -1},
+		{"8.0.456", "8.0.456+1", -1},
 	}
 	for _, c := range cases {
 		t.Run(fmt.Sprintf("%q vs %q", c.v1, c.v2), func(t *testing.T) {
