@@ -7,6 +7,10 @@ import (
 	"github.com/anchore/syft/syft/cpe"
 )
 
+// ErrUnsupportedVersion is returned when a version string cannot be parsed into a rich version object
+// for a known unsupported case (e.g. golang "devel" version).
+var ErrUnsupportedVersion = fmt.Errorf("unsupported version value")
+
 type Version struct {
 	Raw    string
 	Format Format
@@ -18,6 +22,7 @@ type rich struct {
 	semVer        *semanticVersion
 	apkVer        *apkVersion
 	debVer        *debVersion
+	golangVersion *golangVersion
 	mavenVer      *mavenVersion
 	rpmVer        *rpmVersion
 	kbVer         *kbVersion
@@ -63,6 +68,10 @@ func (v *Version) populate() error {
 		ver, err := newDebVersion(v.Raw)
 		v.rich.debVer = ver
 		return err
+	case GolangFormat:
+		ver, err := newGolangVersion(v.Raw)
+		v.rich.golangVersion = ver
+		return err
 	case MavenFormat:
 		ver, err := newMavenVersion(v.Raw)
 		v.rich.mavenVer = ver
