@@ -15,6 +15,8 @@ type Metadata struct {
 }
 
 type Cvss struct {
+	Source         string
+	Type           string
 	Version        string
 	Vector         string
 	Metrics        CvssMetrics
@@ -47,6 +49,8 @@ func NewCvss(m []grypeDB.Cvss) []Cvss {
 	var cvss []Cvss
 	for _, score := range m {
 		cvss = append(cvss, Cvss{
+			Source:  score.Source,
+			Type:    score.Type,
 			Version: score.Version,
 			Vector:  score.Vector,
 			Metrics: CvssMetrics{
