@@ -3,6 +3,7 @@ package vulnerability
 import (
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/pkg"
+	"github.com/anchore/syft/syft/cpe"
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
@@ -22,7 +23,7 @@ type ProviderByLanguage interface {
 }
 
 type ProviderByCPE interface {
-	GetByCPE(syftPkg.CPE) ([]Vulnerability, error)
+	GetByCPE(cpe.CPE) ([]Vulnerability, error)
 }
 
 type MetadataProvider interface {
