@@ -6,10 +6,15 @@ import (
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/google/uuid"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	"github.com/wagoodman/go-partybus"
 
 	"github.com/anchore/grype/grype/db"
 	grypeDB "github.com/anchore/grype/grype/db/v5"
+	"github.com/anchore/grype/grype/distro"
+	"github.com/anchore/grype/grype/event"
+	"github.com/anchore/grype/grype/event/monitor"
 	"github.com/anchore/grype/grype/grypeerr"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/matcher"
@@ -19,10 +24,14 @@ import (
 	"github.com/anchore/grype/grype/search"
 	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/version"
+	"github.com/anchore/grype/grype/vex"
 	"github.com/anchore/grype/grype/vulnerability"
+	"github.com/anchore/grype/internal/bus"
 	"github.com/anchore/syft/syft/cpe"
+	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/linux"
 	syftPkg "github.com/anchore/syft/syft/pkg"
+	"github.com/anchore/syft/syft/source"
 )
 
 type ack interface {
@@ -39,20 +48,66 @@ type mockStore struct {
 }
 
 func (d *mockStore) GetVulnerabilityMatchExclusion(id string) ([]grypeDB.VulnerabilityMatchExclusion, error) {
-	//panic("implement me")
+	// panic("implement me")
 	return nil, nil
 }
 
-func newMockStore() *mockStore {
-	d := mockStore{
+// A mockStoreStubFn takes a reference to a mockStore and mutates it to contain
+// a set of prescribed test data.
+type mockStoreStubFn func(*mockStore)
+
+// newMockStore returns a new mock implementation of a Grype database store. If
+// the stubFn parameter is not set to nil, the given stub function will be used
+// to modify the data in the mock store, such as in preparation for tests.
+func newMockStore(stubFn mockStoreStubFn) *mockStore {
+	d := &mockStore{
 		vulnerabilities: make(map[string]map[string][]grypeDB.Vulnerability),
 		metadata:        make(map[string]map[string]*grypeDB.VulnerabilityMetadata),
 	}
-	d.stub()
-	return &d
+	if stubFn != nil {
+		stubFn(d)
+	}
+	return d
 }
 
-func (d *mockStore) stub() {
+func (d *mockStore) GetVulnerabilityMetadata(id, namespace string) (*grypeDB.VulnerabilityMetadata, error) {
+	return d.metadata[id][namespace], nil
+}
+
+func (d *mockStore) GetAllVulnerabilityMetadata() (*[]grypeDB.VulnerabilityMetadata, error) {
+	panic("implement me")
+}
+
+func (d *mockStore) GetVulnerability(namespace, id string) ([]grypeDB.Vulnerability, error) {
+	var results []grypeDB.Vulnerability
+	for _, vulns := range d.vulnerabilities[namespace] {
+		for _, vuln := range vulns {
+			if vuln.ID == id {
+				results = append(results, vuln)
+			}
+		}
+	}
+	return results, nil
+}
+
+func (d *mockStore) SearchForVulnerabilities(namespace, name string) ([]grypeDB.Vulnerability, error) {
+	return d.vulnerabilities[namespace][name], nil
+}
+
+func (d *mockStore) GetAllVulnerabilities() (*[]grypeDB.Vulnerability, error) {
+	panic("implement me")
+}
+
+func (d *mockStore) GetVulnerabilityNamespaces() ([]string, error) {
+	keys := make([]string, 0, len(d.vulnerabilities))
+	for k := range d.vulnerabilities {
+		keys = append(keys, k)
+	}
+
+	return keys, nil
+}
+
+func defaultStubFn(d *mockStore) {
 	// METADATA /////////////////////////////////////////////////////////////////////////////////
 	d.metadata["CVE-2014-fake-1"] = map[string]*grypeDB.VulnerabilityMetadata{
 		"debian:distro:debian:8": {
@@ -160,43 +215,6 @@ func (d *mockStore) stub() {
 	}
 }
 
-func (d *mockStore) GetVulnerabilityMetadata(id, namespace string) (*grypeDB.VulnerabilityMetadata, error) {
-	return d.metadata[id][namespace], nil
-}
-
-func (d *mockStore) GetAllVulnerabilityMetadata() (*[]grypeDB.VulnerabilityMetadata, error) {
-	panic("implement me")
-}
-
-func (d *mockStore) GetVulnerability(namespace, id string) ([]grypeDB.Vulnerability, error) {
-	var results []grypeDB.Vulnerability
-	for _, vulns := range d.vulnerabilities[namespace] {
-		for _, vuln := range vulns {
-			if vuln.ID == id {
-				results = append(results, vuln)
-			}
-		}
-	}
-	return results, nil
-}
-
-func (d *mockStore) SearchForVulnerabilities(namespace, name string) ([]grypeDB.Vulnerability, error) {
-	return d.vulnerabilities[namespace][name], nil
-}
-
-func (d *mockStore) GetAllVulnerabilities() (*[]grypeDB.Vulnerability, error) {
-	panic("implement me")
-}
-
-func (d *mockStore) GetVulnerabilityNamespaces() ([]string, error) {
-	keys := make([]string, 0, len(d.vulnerabilities))
-	for k := range d.vulnerabilities {
-		keys = append(keys, k)
-	}
-
-	return keys, nil
-}
-
 func Test_HasSeverityAtOrAbove(t *testing.T) {
 	thePkg := pkg.Package{
 		ID:      pkg.ID(uuid.NewString()),
@@ -251,7 +269,7 @@ func Test_HasSeverityAtOrAbove(t *testing.T) {
 		},
 	}
 
-	metadataProvider := db.NewVulnerabilityMetadataProvider(newMockStore())
+	metadataProvider := db.NewVulnerabilityMetadataProvider(newMockStore(defaultStubFn))
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
@@ -274,7 +292,7 @@ func Test_HasSeverityAtOrAbove(t *testing.T) {
 }
 
 func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
-	mkStr := newMockStore()
+	mkStr := newMockStore(defaultStubFn)
 	vp, err := db.NewVulnerabilityProvider(mkStr)
 	require.NoError(t, err)
 	str := store.Store{
@@ -291,7 +309,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 	}
 
 	mustCPE := func(c string) cpe.CPE {
-		cp, err := cpe.New(c)
+		cp, err := cpe.New(c, "")
 		if err != nil {
 			t.Fatal(err)
 		}
@@ -315,6 +333,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 		IgnoreRules    []match.IgnoreRule
 		FailSeverity   *vulnerability.Severity
 		NormalizeByCVE bool
+		VexProcessor   *vex.Processor
 	}
 	type args struct {
 		pkgs    []pkg.Package
@@ -454,6 +473,86 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantIgnoredMatches: nil,
 			wantErr:            grypeerr.ErrAboveSeverityThreshold,
 		},
+		{
+			name: "pass on severity threshold with VEX",
+			fields: fields{
+				Store:    str,
+				Matchers: matcher.NewDefaultMatchers(matcher.Config{}),
+				FailSeverity: func() *vulnerability.Severity {
+					x := vulnerability.LowSeverity
+					return &x
+				}(),
+				VexProcessor: vex.NewProcessor(vex.ProcessorOptions{
+					Documents: []string{
+						"vex/testdata/vex-docs/openvex-debian.json",
+					},
+					IgnoreRules: []match.IgnoreRule{
+						{
+							VexStatus: "fixed",
+						},
+					},
+				}),
+			},
+			args: args{
+				pkgs: []pkg.Package{
+					neutron2013Pkg,
+				},
+				context: pkg.Context{
+					Source: &source.Description{
+						Name:    "debian",
+						Version: "2013.1.1-1",
+						Metadata: source.ImageMetadata{
+							RepoDigests: []string{
+								"debian@sha256:124c7d2707904eea7431fffe91522a01e5a861a624ee31d03372cc1d138a3126",
+							},
+						},
+					},
+					Distro: &linux.Release{
+						ID:        "debian",
+						VersionID: "8",
+					},
+				},
+			},
+			wantMatches: match.NewMatches(),
+			wantIgnoredMatches: []match.IgnoredMatch{
+				{
+					AppliedIgnoreRules: []match.IgnoreRule{
+						{
+							Namespace: "vex",
+							VexStatus: "fixed",
+						},
+					},
+					Match: match.Match{
+						Vulnerability: vulnerability.Vulnerability{
+							Constraint:        version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
+							ID:                "CVE-2014-fake-1",
+							Namespace:         "debian:distro:debian:8",
+							PackageQualifiers: []qualifier.Qualifier{},
+							CPEs:              []cpe.CPE{},
+							Advisories:        []vulnerability.Advisory{},
+						},
+						Package: neutron2013Pkg,
+						Details: match.Details{
+							{
+								Type: match.ExactDirectMatch,
+								SearchedBy: map[string]any{
+									"distro":    map[string]string{"type": "debian", "version": "8"},
+									"namespace": "debian:distro:debian:8",
+									"package":   map[string]string{"name": "neutron", "version": "2013.1.1-1"},
+								},
+								Found: map[string]any{
+									"versionConstraint": "< 2014.1.3-6 (deb)",
+									"vulnerabilityID":   "CVE-2014-fake-1",
+								},
+								Matcher:    "dpkg-matcher",
+								Confidence: 1,
+							},
+						},
+					},
+				},
+			},
+			wantErr: nil,
+		},
 		{
 			name: "matches by exact-direct match (language)",
 			fields: fields{
@@ -690,6 +789,48 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 				},
 			),
 			wantErr: nil,
+			wantIgnoredMatches: []match.IgnoredMatch{
+				{
+					Match: match.Match{
+						Vulnerability: vulnerability.Vulnerability{
+							Constraint:        version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+							ID:                "CVE-2014-fake-3",
+							Namespace:         "nvd:cpe",
+							CPEs:              []cpe.CPE{},
+							PackageQualifiers: []qualifier.Qualifier{},
+							Advisories:        []vulnerability.Advisory{},
+							RelatedVulnerabilities: []vulnerability.Reference{
+								{
+									ID:        "GHSA-2014-fake-3",
+									Namespace: "github:language:ruby",
+								},
+							},
+						},
+						Package: activerecordPkg,
+						Details: match.Details{
+							{
+								Type: match.ExactDirectMatch,
+								SearchedBy: map[string]any{
+									"language":  "ruby",
+									"namespace": "github:language:ruby",
+									"package":   map[string]string{"name": "activerecord", "version": "3.7.5"},
+								},
+								Found: map[string]any{
+									"versionConstraint": "< 3.7.6 (unknown)",
+									"vulnerabilityID":   "GHSA-2014-fake-3",
+								},
+								Matcher:    "ruby-gem-matcher",
+								Confidence: 1,
+							},
+						},
+					},
+					AppliedIgnoreRules: []match.IgnoreRule{
+						{
+							Vulnerability: "GHSA-2014-fake-3",
+						},
+					},
+				},
+			},
 		},
 		{
 			name: "normalize by cve -- ignore CVE",
@@ -717,6 +858,51 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			},
 			wantMatches: match.NewMatches(),
 			wantIgnoredMatches: []match.IgnoredMatch{
+				{
+					Match: match.Match{
+						Vulnerability: vulnerability.Vulnerability{
+							Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+							ID:         "CVE-2014-fake-3",
+							Namespace:  "nvd:cpe",
+							CPEs: []cpe.CPE{
+								mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
+							},
+							PackageQualifiers:      []qualifier.Qualifier{},
+							Advisories:             []vulnerability.Advisory{},
+							RelatedVulnerabilities: nil,
+						},
+						Package: activerecordPkg,
+						Details: match.Details{
+							{
+								Type: match.CPEMatch,
+								SearchedBy: search.CPEParameters{
+									Namespace: "nvd:cpe",
+									CPEs: []string{
+										"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
+									},
+									Package: search.CPEPackageParameter{
+										Name:    "activerecord",
+										Version: "3.7.5",
+									},
+								},
+								Found: search.CPEResult{
+									VulnerabilityID:   "CVE-2014-fake-3",
+									VersionConstraint: "< 3.7.6 (unknown)",
+									CPEs: []string{
+										"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
+									},
+								},
+								Matcher:    "ruby-gem-matcher",
+								Confidence: 0.9,
+							},
+						},
+					},
+					AppliedIgnoreRules: []match.IgnoreRule{
+						{
+							Vulnerability: "CVE-2014-fake-3",
+						},
+					},
+				},
 				{
 					AppliedIgnoreRules: []match.IgnoreRule{
 						{
@@ -872,7 +1058,13 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 				IgnoreRules:    tt.fields.IgnoreRules,
 				FailSeverity:   tt.fields.FailSeverity,
 				NormalizeByCVE: tt.fields.NormalizeByCVE,
+				VexProcessor:   tt.fields.VexProcessor,
 			}
+
+			listener := &busListener{}
+			bus.Set(listener)
+			defer bus.Set(nil)
+
 			actualMatches, actualIgnoreMatches, err := m.FindMatches(tt.args.pkgs, tt.args.context)
 			if tt.wantErr != nil {
 				require.ErrorIs(t, err, tt.wantErr)
@@ -896,6 +1088,309 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			if d := cmp.Diff(tt.wantIgnoredMatches, actualIgnoreMatches, opts...); d != "" {
 				t.Errorf("FindMatches() ignored matches mismatch [ha!] (-want +got):\n%s", d)
 			}
+
+			// validate the bus-reported ignored counts are accurate
+			require.Equal(t, int64(len(tt.wantIgnoredMatches)), listener.matching.Ignored.Current())
 		})
 	}
 }
+
+func Test_indexFalsePositivesByLocation(t *testing.T) {
+	cases := []struct {
+		name           string
+		d              distro.Distro
+		pkgs           []pkg.Package
+		stubFunc       mockStoreStubFn
+		expectedResult map[string][]string
+		errAssertion   assert.ErrorAssertionFunc
+	}{
+		{
+			name: "false positive in wolfi package adds index entry",
+			d:    distro.Distro{Type: distro.Wolfi},
+			pkgs: []pkg.Package{
+				{
+					Name: "foo",
+					Metadata: pkg.ApkMetadata{Files: []pkg.ApkFileRecord{
+						{
+							Path: "/bin/foo-binary",
+						},
+					}},
+				},
+			},
+			stubFunc: func(d *mockStore) {
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+					"foo": {
+						{
+							ID:                "GHSA-2014-fake-3",
+							PackageName:       "foo",
+							Namespace:         "wolfi:distro:wolfi:rolling",
+							VersionConstraint: "< 0",
+							VersionFormat:     "apk",
+						},
+					},
+				}
+			},
+			expectedResult: map[string][]string{
+				"/bin/foo-binary": {"GHSA-2014-fake-3"},
+			},
+			errAssertion: assert.NoError,
+		},
+		{
+			name: "false positive in wolfi subpackage adds index entry",
+			d:    distro.Distro{Type: distro.Wolfi},
+			pkgs: []pkg.Package{
+				{
+					Name: "subpackage-foo",
+					Metadata: pkg.ApkMetadata{Files: []pkg.ApkFileRecord{
+						{
+							Path: "/bin/foo-subpackage-binary",
+						},
+					}},
+					Upstreams: []pkg.UpstreamPackage{
+						{
+							Name: "origin-foo",
+						},
+					},
+				},
+			},
+			stubFunc: func(d *mockStore) {
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+					"origin-foo": {
+						{
+							ID:                "GHSA-2014-fake-3",
+							PackageName:       "foo",
+							Namespace:         "wolfi:distro:wolfi:rolling",
+							VersionConstraint: "< 0",
+							VersionFormat:     "apk",
+						},
+					},
+				}
+			},
+			expectedResult: map[string][]string{
+				"/bin/foo-subpackage-binary": {"GHSA-2014-fake-3"},
+			},
+			errAssertion: assert.NoError,
+		},
+		{
+			name: "fixed vuln (not a false positive) in wolfi package",
+			d:    distro.Distro{Type: distro.Wolfi},
+			pkgs: []pkg.Package{
+				{
+					Name: "foo",
+					Metadata: pkg.ApkMetadata{Files: []pkg.ApkFileRecord{
+						{
+							Path: "/bin/foo-binary",
+						},
+					}},
+				},
+			},
+			stubFunc: func(d *mockStore) {
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+					"foo": {
+						{
+							ID:                "GHSA-2014-fake-3",
+							PackageName:       "foo",
+							Namespace:         "wolfi:distro:wolfi:rolling",
+							VersionConstraint: "< 1.2.3-r4",
+							VersionFormat:     "apk",
+						},
+					},
+				}
+			},
+			expectedResult: map[string][]string{},
+			errAssertion:   assert.NoError,
+		},
+		{
+			name: "no vuln data for wolfi package",
+			d:    distro.Distro{Type: distro.Wolfi},
+			pkgs: []pkg.Package{
+				{
+					Name: "foo",
+					Metadata: pkg.ApkMetadata{Files: []pkg.ApkFileRecord{
+						{
+							Path: "/bin/foo-binary",
+						},
+					}},
+				},
+			},
+			stubFunc: func(d *mockStore) {
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{}
+			},
+			expectedResult: map[string][]string{},
+			errAssertion:   assert.NoError,
+		},
+		{
+			name: "no files listed for a wolfi package",
+			d:    distro.Distro{Type: distro.Wolfi},
+			pkgs: []pkg.Package{
+				{
+					Name:     "foo",
+					Metadata: pkg.ApkMetadata{Files: nil},
+				},
+			},
+			stubFunc: func(d *mockStore) {
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+					"foo": {
+						{
+							ID:                "GHSA-2014-fake-3",
+							PackageName:       "foo",
+							Namespace:         "wolfi:distro:wolfi:rolling",
+							VersionConstraint: "< 0",
+							VersionFormat:     "apk",
+						},
+					},
+				}
+			},
+			expectedResult: map[string][]string{},
+			errAssertion:   assert.NoError,
+		},
+	}
+
+	for _, tt := range cases {
+		t.Run(tt.name, func(t *testing.T) {
+			s := createMockStore(t, tt.stubFunc)
+			actualResult, err := indexFalsePositivesByLocation(&tt.d, tt.pkgs, s)
+			tt.errAssertion(t, err)
+			assert.Equal(t, tt.expectedResult, actualResult)
+		})
+	}
+}
+
+func createMockStore(t *testing.T, fn mockStoreStubFn) store.Store {
+	t.Helper()
+
+	mkStr := newMockStore(fn)
+	vp, err := db.NewVulnerabilityProvider(mkStr)
+	require.NoError(t, err)
+
+	return store.Store{
+		Provider:          vp,
+		MetadataProvider:  db.NewVulnerabilityMetadataProvider(mkStr),
+		ExclusionProvider: db.NewMatchExclusionProvider(mkStr),
+	}
+}
+
+func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
+	cases := []struct {
+		name         string
+		inputMatches []match.Match
+		fpIndex      map[string][]string
+		expected     []match.Match
+	}{
+		{
+			name:         "no input matches",
+			inputMatches: nil,
+			fpIndex: map[string][]string{
+				"/usr/bin/crane": {"CVE-2014-fake-3"},
+			},
+			expected: nil,
+		},
+		{
+			name: "happy path filtering",
+			inputMatches: []match.Match{
+				{
+					Package: pkg.Package{
+						Name:      "crane",
+						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
+					},
+					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+				},
+			},
+			fpIndex: map[string][]string{
+				"/usr/bin/crane": {"CVE-2014-fake-3"},
+			},
+			expected: nil,
+		},
+		{
+			name: "location match but no vulns in FP index",
+			inputMatches: []match.Match{
+				{
+					Package: pkg.Package{
+						Name:      "crane",
+						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
+					},
+					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+				},
+			},
+			fpIndex: map[string][]string{
+				"/usr/bin/crane": {},
+			},
+			expected: []match.Match{
+				{
+					Package: pkg.Package{
+						Name:      "crane",
+						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
+					},
+					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+				},
+			},
+		},
+		{
+			name: "location match but matched vuln not in FP index",
+			inputMatches: []match.Match{
+				{
+					Package: pkg.Package{
+						Name:      "crane",
+						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
+					},
+					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+				},
+			},
+			fpIndex: map[string][]string{
+				"/usr/bin/crane": {"CVE-2016-fake-3"},
+			},
+			expected: []match.Match{
+				{
+					Package: pkg.Package{
+						Name:      "crane",
+						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
+					},
+					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+				},
+			},
+		},
+		{
+			name: "empty FP index",
+			inputMatches: []match.Match{
+				{
+					Package: pkg.Package{
+						Name:      "crane",
+						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
+					},
+					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+				},
+			},
+			fpIndex: map[string][]string{},
+			expected: []match.Match{
+				{
+					Package: pkg.Package{
+						Name:      "crane",
+						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
+					},
+					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+				},
+			},
+		},
+	}
+
+	for _, tt := range cases {
+		t.Run(tt.name, func(t *testing.T) {
+			actual := filterMatchesUsingDistroFalsePositives(tt.inputMatches, tt.fpIndex)
+			assert.Equal(t, tt.expected, actual)
+		})
+	}
+}
+
+type busListener struct {
+	matching monitor.Matching
+}
+
+func (b *busListener) Publish(e partybus.Event) {
+	if e.Type == event.VulnerabilityScanningStarted {
+		if m, ok := e.Value.(monitor.Matching); ok {
+			b.matching = m
+		}
+	}
+}
+
+var _ partybus.Publisher = (*busListener)(nil)
