@@ -19,17 +19,6 @@ import (
 	"github.com/anchore/syft/syft/source"
 )
 
-var imagesWithVulnerabilities = []string{
-	"anchore/test_images:vulnerabilities-alpine",
-	"anchore/test_images:gems",
-	"anchore/test_images:vulnerabilities-debian",
-	"anchore/test_images:vulnerabilities-centos",
-	"anchore/test_images:npm",
-	"anchore/test_images:java",
-	"anchore/test_images:golang-56d52bc",
-	"anchore/test_images:arch",
-}
-
 func getListingURL() string {
 	if value, ok := os.LookupEnv("GRYPE_DB_UPDATE_URL"); ok {
 		return value
@@ -64,6 +53,7 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 	// exceptions: rust, php, dart, msrc (kb), etc. are not under test
 	definedPkgTypes.Remove(
 		string(syftPkg.BinaryPkg), // these are removed due to overlap-by-file-ownership
+		string(syftPkg.PhpPeclPkg),
 		string(syftPkg.RustPkg),
 		string(syftPkg.KbPkg),
 		string(syftPkg.DartPubPkg),
@@ -82,6 +72,9 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 		string(syftPkg.SwiftPkg),
 		string(syftPkg.GithubActionPkg),
 		string(syftPkg.GithubActionWorkflowPkg),
+		string(syftPkg.ErlangOTPPkg),
+		string(syftPkg.WordpressPluginPkg), // TODO: remove me when there is a matcher for this merged in https://github.com/anchore/grype/pull/1553
+		string(syftPkg.LuaRocksPkg),
 	)
 	observedPkgTypes := strset.New()
 	testCases := []struct {
@@ -235,11 +228,10 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 	}
 	for _, tc := range testCases {
 		imageArchive := PullThroughImageCache(t, tc.image)
-		imageSource := fmt.Sprintf("docker-archive:%s", imageArchive)
 
 		t.Run(tc.name, func(t *testing.T) {
 			// get SBOM from syft, write to temp file
-			sbomBytes := getSyftSBOM(t, imageSource, tc.format)
+			sbomBytes := getSyftSBOM(t, imageArchive, "docker-archive", tc.format)
 			sbomFile, err := os.CreateTemp("", "")
 			assert.NoError(t, err)
 			t.Cleanup(func() {
@@ -254,6 +246,7 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 			assert.NoError(t, err)
 
 			// get vulns (image)
+			imageSource := fmt.Sprintf("docker-archive:%s", imageArchive)
 			matchesFromImage, _, _, err := grype.FindVulnerabilities(*store, imageSource, source.SquashedScope, nil)
 			assert.NoError(t, err)
 
